version 17

log close _all
clear all
macro drop _all
set linesize 82

log using "./logs/example ini-file.smcl", replace name(master)



**# HEADER
**========
type ./header.txt





**#1. Load Settings (from .do)
**============================
file open ini using "./config/settings.ini", read

file read ini line
while r(eof)==0 {
	local first_char = usubstr(ustrltrim(`"`line'"'), 1, 1)
    if inlist("`first_char'", "", ";", "[")  {
        // do nothing, i.e. skip blank lines, comments (;) and section headings
    }
    
    else {    
        local pos = ustrpos(`"`line'"', "=")
        local name = usubstr(`"`line'"', 1, `=`pos'-1')
        local content = ustrtrim(usubstr(`"`line'"', `=`pos'+1', .))
        global `name' = `"`content'"'
    }
    
    file read ini line
}

file close ini








**#2. Compute Grades from Exam Data:
*===================================
macro list rawdata
use "$rawdata", clear


do ./code/grading








**#3. Export anonymous grades list:
*==================================
label var ID        "Student ID"
label var total     "Total points"
label var grade     "Overall grade"

export excel  ID total grade  using "$gradeslist", ///
  firstrow(varlabels) replace








**#4. Plot Grade Distribution
*============================
preserve
    gen one = 1
    collapse (count) freq=one , by(grade)

    sum freq
    
    graph bar (asis) freq, over(grade, label(labcolor($text_color)))  ///
        title(`"Grade Distribution {it:"$title"}"', color($text_color) span)  ///
        ytitle("")  ///
        ylabel(, angle(0) labcolor($text_color))  ///
        bar(1, color($bar_color))  ///
        blabel(bar, pos(inside) color(white))  ///
        caption("{it:N} = `r(sum)'", color($text_color) position(5))  ///
        graphregion(color(white))

    graph export "./results/barplot grades $shorttitle $term.svg", replace
restore




********************************************************************************
log close master
translate "./logs/example ini-file.smcl" "./logs/example ini-file.pdf", replace
exit
